package com.example.myapplication.ui.home;

import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.NavController;
import androidx.navigation.fragment.NavHostFragment;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.SortedList;

import com.example.myapplication.CustomAdapter;
import com.example.myapplication.MainActivity2;
import com.example.myapplication.R;
import com.example.myapplication.RecyclerItemClickListener;
import com.example.myapplication.WeatherData;
import com.example.myapplication.databinding.FragmentHomeBinding;
import com.example.myapplication.ui.gallery.GalleryFragment;
import com.google.gson.JsonArray;
import com.google.gson.JsonObject;

import java.io.Console;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.logging.Logger;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;
import retrofit2.Retrofit;
import retrofit2.converter.gson.GsonConverterFactory;
import retrofit2.http.GET;

public class HomeFragment extends Fragment   {

    private FragmentHomeBinding binding;
    private WeatherService service;
    private ArrayList<WeatherData> weatherDataList = new ArrayList<>();

    public View onCreateView(@NonNull LayoutInflater inflater,
                             ViewGroup container, Bundle savedInstanceState) {
        HomeViewModel homeViewModel =
                new ViewModelProvider(this).get(HomeViewModel.class);

        binding = FragmentHomeBinding.inflate(inflater, container, false);
        View root = binding.getRoot();

        Retrofit retrofit = new Retrofit.Builder()
                .baseUrl("https://raw.githubusercontent.com/Lpirskaya/JsonLab/refs/heads/master/")
                .addConverterFactory(GsonConverterFactory.create())
                .build();
        service = retrofit.create(WeatherService.class);

//        String[] city_list = getResources().getStringArray(R.array.city_list);
//        Arrays.sort(city_list);

        RecyclerView recyclerView = root.findViewById(R.id.suslik);
        recyclerView.addOnItemTouchListener(new RecyclerItemClickListener(root.getContext(), recyclerView ,new RecyclerItemClickListener.OnItemClickListener() {
            @Override public void onItemClick(View view, int position) {
                Log.e("HomeFragment", "onClick: " + weatherDataList.get(position).City);
                if (getActivity() instanceof MainActivity2) {
                    ((MainActivity2) getActivity()).setCurrentCity(weatherDataList.get(position));
                }
            }

            @Override
            public void onLongItemClick(View view, int position) {

            }
        }));
        recyclerView.setLayoutManager(new LinearLayoutManager(root.getContext()));
        CustomAdapter adapter = new CustomAdapter(weatherDataList);
        recyclerView.setAdapter(adapter);

        return root;
    }

    public interface WeatherService {
        @GET("Weather2022.json")
        Call<JsonArray> getWeather2022();
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }


    @Override
    public void onResume() {
        super.onResume();
        service.getWeather2022().enqueue(new Callback<JsonArray>() {
            @Override
            public void onResponse(Call<JsonArray> call, Response<JsonArray> response) {
                if (response.isSuccessful()) {
                    JsonArray weatherData = response.body();
                    Log.d("HomeFragment", "Weather data: " + weatherData);
                    weatherDataList = new ArrayList<>(weatherData.size());
                    for (int i = 0; i < weatherData.size(); i++) {
                        weatherDataList.add(new WeatherData(
                                weatherData.get(i).getAsJsonObject().get("City").getAsString(),
                                weatherData.get(i).getAsJsonObject().get("Temperature").getAsString(),
                                weatherData.get(i).getAsJsonObject().get("WeatherCondition").getAsString(),
                                weatherData.get(i).getAsJsonObject().get("AtmosphericPressure").getAsString(),
                                weatherData.get(i).getAsJsonObject().get("Wind").getAsString()
                        ));

                        weatherDataList.sort((o1, o2) -> o1.City.compareTo(o2.City));
//                        JsonObject item = weatherData.get(i).getAsJsonObject();
//                        Log.i("HomeFragment", "City: " + item.get("City").getAsString());
//                        Log.i("HomeFragment", "Temperature: " + item.get("Temperature").getAsInt());
//                        Log.i("HomeFragment", "WeatherCondition: " + item.get("WeatherCondition").getAsString());
//                        Log.i("HomeFragment", "AtmosphericPressure: " + item.get("AtmosphericPressure").getAsString());
//                        Log.i("HomeFragment", "Wind: " + item.get("Wind").getAsString());
//                        Log.i("HomeFragment", "-------------------");
                    }
                } else
                    Log.e("HomeFragment", "Request failed: " + response.message());
            }

            @Override
            public void onFailure(Call<JsonArray> call, Throwable t) {
                Log.e("HomeFragment", "Network request failed", t);
            }
        });
    }
}